@@ -1,22 +1,45 @@
 #[cfg(test)]
 mod tests {
+// This library
+    // stats
     use crate::stats::Builder;
     use crate::stats::Basic as Stats;
     use crate::stats::Normal as StatsNormal;
-    use crate::class::Basic as Class;
     use crate::stats::BasicPremade as BasicPremade;
     use crate::stats::NormalPremade as NormalPremade;
+    
+    // class
+    use crate::class::Basic as Class;
+    
+    // legendary
     use crate::legendary::Legendary;
-    use crate::types::Special;
+    
+    // special
+    use crate::special::ManaCost;
+    use crate::special::Normal as Special;
+
+    //atributes
+    use crate::attributes::Effectiveness;
+    //use crate::equation::Equation;
+
+// imported libraries
     use std::fs::File;
     use std::io::Read;
     use toml::*;
     use serde::{Deserialize, Serialize};
+    
 
     #[test]
     fn special_type(){
         let grind:Special = Special::Grind;
-        assert_eq!(grind.mp_cost(),7.0);
+        //assert_eq!(grind.mp_cost(),7);
+    }
+    // used in effectiveness test below
+    #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
+    pub struct OccasionalEnemy {
+        pub name:String,
+        pub stats:Stats<f64>,
+        pub effectiveness:Effectiveness<f64>,
     }
     // used in tests below
     #[derive(Clone, PartialEq, Debug, Serialize, Deserialize)]
@@ -177,6 +200,7 @@ mod tests {
                 file.read_to_string(&mut content).unwrap();
                 let decoded: Stats<f64> = toml::from_str(content.as_str()).unwrap();
                 assert_eq!(decoded.hp, 10.0);
+                assert_eq!(decoded.id, 358.0);
             },
             Err(e) => println!("Error:{} opening File:{}", e, filename),
         }
@@ -196,6 +220,29 @@ mod tests {
                 file.read_to_string(&mut content).unwrap();
                 let decoded: Character = toml::from_str(content.as_str()).unwrap();
                 assert_eq!(decoded.hp(), 10.0);
+                assert_eq!(decoded.name, String::from("Easter Bilby"));
+            },
+            Err(e) => println!("Error:{} opening File:{}", e, filename),
+        }
+    }
+    #[test]
+    fn effectiveness_test_0(){
+         let mut player:Player = Player::empty();
+         player.set_hp(100.0);
+        let effectiveness:Effectiveness<f64> = Effectiveness::Half(player.hp());
+        assert_eq!(50.0, effectiveness.value());
+    }
+    #[test]
+    fn effectiveness_test_1(){
+        let filename = "assets/characters/Aatxe.ini";
+        match File::open(filename) {
+            Ok(mut file) => {
+                let mut content = String::new();
+                file.read_to_string(&mut content).unwrap();
+                let decoded: OccasionalEnemy = toml::from_str(content.as_str()).unwrap();
+                assert_eq!(decoded.stats.hp, 10.0);
+                assert_eq!(decoded.effectiveness, Effectiveness::Double(50.0));
+                assert_eq!(decoded.name, String::from("Easter Bilby"));
             },
             Err(e) => println!("Error:{} opening File:{}", e, filename),
         }
